/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.intelliform;

import java.util.List;

import de.ozgcloud.eingang.common.formdata.IncomingFileTestFactory;

public class DepositTestFactory {

	public static final String ATTACHMENT1_NAME = IncomingFileTestFactory.NAME;
	public static final String ATTACHMENT1_ID = IncomingFileTestFactory.VENDOR_ID;
	public static final String ATTACHMENT1_CONTENT_TYPE = IncomingFileTestFactory.CONTENT_TYPE;
	public static final byte[] ATTACHMENT1_CONTENT = IncomingFileTestFactory.CONTENT;

	public static final String ATTACHMENT2_NAME = "Scan1.pdf";
	public static final String ATTACHMENT2_ID = "VendorId2222";
	public static final String ATTACHMENT2_CONTENT_TYPE = "application/pdf";
	public static final byte[] ATTACHMENT2_CONTENT = "TestContent2".getBytes();

	public static final List<Attachment> ATTACHMENTS = List.of(AttachmentTestFactory.createXmlDaten(), AttachmentTestFactory.createPdf());

	public static Deposit create() {
		return DepositTestFactory.withAttachments(ATTACHMENTS);
	}

	static Deposit withData(DepositData data) {
		Deposit deposit = new Deposit();
		data.setPrimaryDataAttachmentId(AttachmentTestFactory.XML_ID);
		deposit.setData(data);

		return deposit;
	}

	static Deposit withAttachments(List<Attachment> attachments) {
		Deposit deposit = DepositTestFactory.withData(new DepositData());
		deposit.getData().getAttachments().addAll(attachments);
		return deposit;
	}
}
