/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.intelliform;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.io.IOException;
import java.net.URISyntaxException;

import javax.xml.parsers.ParserConfigurationException;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.xml.sax.SAXException;

import de.ozgcloud.common.test.TestUtils;
import de.ozgcloud.eingang.common.formdata.FormDataTestFactory;
import de.ozgcloud.eingang.semantik.SemantikAdapter;

class FormDataEndpointTest {

	@InjectMocks
	private FormDataEndpoint formdataEndpoint;
	@Mock
	private SemantikFormDataMapper semantikFormDataMapper;
	@Mock
	private SemantikAdapter semantikAdapter;

	@BeforeEach
	void init() throws SAXException, IOException, ParserConfigurationException {
		when(semantikFormDataMapper.mapToFormData(any())).thenReturn(FormDataTestFactory.create());
	}

	@Test
	void testDepositFormData() throws SAXException, IOException, ParserConfigurationException, URISyntaxException {
		var response = formdataEndpoint.inputFormData(buildRequest("intelliform/XML-Daten-1.xml"));

		assertThat(response).isNotNull();
	}

	private Deposit buildRequest(String fileName) throws SAXException, IOException, ParserConfigurationException, URISyntaxException {

		var depositData = new DepositData();

		var attachment = new Attachment();
		attachment.setName("XML-Daten.xml");
		attachment.setContent(TestUtils.loadTextFile(fileName).getBytes());

		depositData.getAttachments()
				.add(attachment);

		var deposit = new Deposit();
		deposit.setData(depositData);

		return deposit;
	}
}
